==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-admin/lxqt-admin-time/lxqt-admin-time_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>DateTime</name>
    <message>
        <location filename="../../datetime.ui" line="23"/>
        <source>Time:</source>
        <translation>Heure :</translation>
    </message>
    <message>
        <location filename="../../datetime.ui" line="39"/>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <location filename="../../datetime.ui" line="53"/>
        <source>Date:</source>
        <translation>Date :</translation>
    </message>
    <message>
        <location filename="../../datetime.ui" line="70"/>
        <source>Enable network time synchronization (NTP)</source>
        <translation>Valider la synchronisation par le réseau (NTP)</translation>
    </message>
    <message>
        <location filename="../../datetime.ui" line="77"/>
        <source>RTC is in local time</source>
        <translation>RTC en heure locale</translation>
    </message>
</context>
<context>
    <name>TimeAdminDialog</name>
    <message>
        <location filename="../../timeadmindialog.cpp" line="42"/>
        <source>Time and date configuration</source>
        <translation>Configuration de la date et de l&apos;heure</translation>
    </message>
    <message>
        <location filename="../../timeadmindialog.cpp" line="48"/>
        <source>Date and time</source>
        <translation>Date et heure</translation>
    </message>
    <message>
        <location filename="../../timeadmindialog.cpp" line="56"/>
        <source>Timezone</source>
        <translation>Zone horaire</translation>
    </message>
    <message>
        <location filename="../../timeadmindialog.cpp" line="117"/>
        <location filename="../../timeadmindialog.cpp" line="127"/>
        <location filename="../../timeadmindialog.cpp" line="134"/>
        <location filename="../../timeadmindialog.cpp" line="144"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
</context>
<context>
    <name>Timezone</name>
    <message>
        <location filename="../../timezone.ui" line="19"/>
        <source>Your current timezone:</source>
        <translation>Votre zone horaire actuelle :</translation>
    </message>
    <message>
        <location filename="../../timezone.ui" line="26"/>
        <source>TextLabel</source>
        <translation>Label</translation>
    </message>
    <message>
        <location filename="../../timezone.ui" line="35"/>
        <source>Filter</source>
        <translation>Filtre</translation>
    </message>
</context>
<context>
    <name>TimezonePage</name>
    <message>
        <location filename="../../timezone.cpp" line="42"/>
        <source>None</source>
        <translation>Aucune</translation>
    </message>
</context>
</TS>

==> lxqt-l10n-0.13.0_p20181121.tar.xz: lxqt-l10n-0.13.0_p20181121/lxqt-admin/lxqt-admin-time/lxqt-admin-time_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>DateTime</name>
    <message>
        <location filename="../../../datetime.ui" line="23"/>
        <source>Time:</source>
        <translation>Heure :</translation>
    </message>
    <message>
        <location filename="../../../datetime.ui" line="39"/>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <location filename="../../../datetime.ui" line="53"/>
        <source>Date:</source>
        <translation>Date :</translation>
    </message>
    <message>
        <location filename="../../../datetime.ui" line="70"/>
        <source>Enable network time synchronization (NTP)</source>
        <translation>Valider la synchronisation par le réseau (NTP)</translation>
    </message>
    <message>
        <location filename="../../../datetime.ui" line="77"/>
        <source>RTC is in local time</source>
        <translation>RTC en heure locale</translation>
    </message>
</context>
<context>
    <name>TimeAdminDialog</name>
    <message>
        <location filename="../../../timeadmindialog.cpp" line="42"/>
        <source>Time and date configuration</source>
        <translation>Configuration de la date et de l&apos;heure</translation>
    </message>
    <message>
        <location filename="../../../timeadmindialog.cpp" line="48"/>
        <source>Date and time</source>
        <translation>Date et heure</translation>
    </message>
    <message>
        <location filename="../../../timeadmindialog.cpp" line="56"/>
        <source>Timezone</source>
        <translation>Zone horaire</translation>
    </message>
    <message>
        <location filename="../../../timeadmindialog.cpp" line="117"/>
        <location filename="../../../timeadmindialog.cpp" line="127"/>
        <location filename="../../../timeadmindialog.cpp" line="134"/>
        <location filename="../../../timeadmindialog.cpp" line="144"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
</context>
<context>
    <name>Timezone</name>
    <message>
        <location filename="../../../timezone.ui" line="19"/>
        <source>Your current timezone:</source>
        <translation>Votre zone horaire actuelle :</translation>
    </message>
    <message>
        <location filename="../../../timezone.ui" line="26"/>
        <source>TextLabel</source>
        <translation>Label</translation>
    </message>
    <message>
        <location filename="../../../timezone.ui" line="35"/>
        <source>Filter</source>
        <translation>Filtre</translation>
    </message>
</context>
<context>
    <name>TimezonePage</name>
    <message>
        <location filename="../../../timezone.cpp" line="42"/>
        <source>None</source>
        <translation>Aucune</translation>
    </message>
</context>
</TS>
